==> kmonad-0.4.3-64-x86_64.pkg.tar.zst: usr/share/haskell/register/kmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kmonad
version:              0.4.3
visibility:           public
id:                   kmonad-0.4.3-JuedftiyRPAH08zQ7R8IKJ
key:                  kmonad-0.4.3-JuedftiyRPAH08zQ7R8IKJ
license:              MIT
maintainer:           janssen.dhj@gmail.com
author:               David Janssen
synopsis:             Advanced keyboard remapping utility
description:
    KMonad is a cross-platform command-line utility that runs as a daemon. It
    captures keyboard input (exactly how depends on the OS) and remaps it. The
    mapping is highly configurable, and provides options like (transparent) layer
    overlays, tap-mod buttons, multi-tap buttons, leader-key style buttons, and
    keyboard macros. Functionality heavily inspired by the QMK-firmware.

category:             Application
abi:                  678fb9d4c194ce1bfecadf7c81818b2c
exposed:              True
exposed-modules:
    KMonad.App KMonad.App.Main KMonad.App.Types KMonad.Args
    KMonad.Args.Cmd KMonad.Args.Joiner KMonad.Args.Parser
    KMonad.Args.TH KMonad.Args.Types KMonad.Gesture KMonad.Keyboard
    KMonad.Keyboard.ComposeSeq KMonad.Keyboard.IO
    KMonad.Keyboard.IO.Linux.DeviceSource
    KMonad.Keyboard.IO.Linux.Types KMonad.Keyboard.IO.Linux.UinputSink
    KMonad.Keyboard.Keycode KMonad.Keyboard.Ops KMonad.Keyboard.Types
    KMonad.Model KMonad.Model.Action KMonad.Model.BEnv
    KMonad.Model.Button KMonad.Model.Dispatch KMonad.Model.Hooks
    KMonad.Model.Keymap KMonad.Model.Sluice KMonad.Parsing
    KMonad.Prelude KMonad.Prelude.Definitions KMonad.Prelude.Imports
    KMonad.Util KMonad.Util.LayerStack KMonad.Util.MultiMap
    Paths_kmonad

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/kmonad
hs-libraries:         HSkmonad-0.4.3-JuedftiyRPAH08zQ7R8IKJ
depends:
    base-4.17.2.1 cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    lens-5.2.3-GXFWsxB7RRtIGQiKpxuie1
    megaparsec-9.6.1-KkOPmPbRCEmCvB2XbKT9En mtl-2.2.2
    optparse-applicative-0.17.1.0-4tPjpOfYmOi9nj8To0UB1j
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb
    rio-0.1.22.0-J3Jrfq68YWeKEgCNothzNm template-haskell-2.19.0.0
    time-1.12.2 unix-2.7.3 unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL

haddock-interfaces:   /usr/share/doc/kmonad/html/kmonad.haddock
haddock-html:         /usr/share/doc/kmonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> kmonad-0.4.4-10-x86_64.pkg.tar.zst: usr/share/haskell/register/kmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kmonad
version:              0.4.4
visibility:           public
id:                   kmonad-0.4.4-1qD2mTrXggC1nQ5fkmIHNp
key:                  kmonad-0.4.4-1qD2mTrXggC1nQ5fkmIHNp
license:              MIT
maintainer:           janssen.dhj@gmail.com
author:               David Janssen
synopsis:             Advanced keyboard remapping utility
description:
    KMonad is a cross-platform command-line utility that runs as a daemon. It
    captures keyboard input (exactly how depends on the OS) and remaps it. The
    mapping is highly configurable, and provides options like (transparent) layer
    overlays, tap-mod buttons, multi-tap buttons, leader-key style buttons, and
    keyboard macros. Functionality heavily inspired by the QMK-firmware.

category:             Application
abi:                  83b35b42a413af4a739c93be1d7a3d84
exposed:              True
exposed-modules:
    KMonad.App KMonad.App.Main KMonad.App.Types KMonad.Args
    KMonad.Args.Cmd KMonad.Args.Joiner KMonad.Args.Parser
    KMonad.Args.TH KMonad.Args.Types KMonad.Gesture KMonad.Keyboard
    KMonad.Keyboard.ComposeSeq KMonad.Keyboard.IO
    KMonad.Keyboard.IO.Linux.DeviceSource
    KMonad.Keyboard.IO.Linux.Types KMonad.Keyboard.IO.Linux.UinputSink
    KMonad.Keyboard.IO.Mac.Types KMonad.Keyboard.IO.Windows.Types
    KMonad.Keyboard.Keycode KMonad.Keyboard.Ops KMonad.Keyboard.Types
    KMonad.Model KMonad.Model.Action KMonad.Model.BEnv
    KMonad.Model.Button KMonad.Model.Dispatch KMonad.Model.Hooks
    KMonad.Model.Keymap KMonad.Model.Sluice KMonad.Parsing
    KMonad.Prelude KMonad.Prelude.Definitions KMonad.Prelude.Imports
    KMonad.Util KMonad.Util.LayerStack KMonad.Util.MultiMap
    Paths_kmonad

import-dirs:          /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/kmonad-0.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/kmonad
hs-libraries:         HSkmonad-0.4.4-1qD2mTrXggC1nQ5fkmIHNp
depends:
    base-4.17.2.1 cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    lens-5.3-8ZK9QDANmBT9CZTQ77OGiP
    megaparsec-9.6.1-EGAiipKGhRa2zjyQ3XtPp3 mtl-2.2.2
    optparse-applicative-0.18.1.0-26u6tT1hMVXIAnAEQGbXYx
    resourcet-1.2.6-LvbunWgaFi52yDP9C6hdhe
    rio-0.1.22.0-DF5jw781s81J6ZHNxB3l7N template-haskell-2.19.0.0
    time-1.12.2 transformers-0.5.6.2 unix-2.7.3
    unliftio-0.2.25.1-B1T4fU5SOAMD3xDfl4gy9D

haddock-interfaces:   /usr/share/doc/kmonad/html/kmonad.haddock
haddock-html:         /usr/share/doc/kmonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
